rappsflyer-package: Work with AppsFlyer API

rappsflyer-packageR Documentation

Work with AppsFlyer API

Description

Loading data from AppsFlyer Pull API <https://support.appsflyer.com/hc/en-us/articles/207034346-Pull-API-aggregate-data>.

Details

The DESCRIPTION file: This package was not yet installed at build time.
Index: This package was not yet installed at build time.

Author(s)

Alexey Seleznev [aut, cre] (ORCID: <https://orcid.org/0000-0003-0410-7385>) Maintainer: Alexey Seleznev <selesnow@gmail.com>


rappsflyer documentation built on May 27, 2026, 9:06 a.m.